@@ -50,7 +50,7 @@ class GSPeerConnectionBroadcasterPiCaller:
     def startSocket(self):
         self._logger.debug("start broadcast socket")
         asyncio.run(GSPeerConnectionBroadcasterPiSocketv2.create(self.sio, self.gsdbs, self.camera, self.oncommand,
-                                                           self.setChannel))
+                                                                 self.setChannel))
 
     def getconnectionurl(self):
         connectURL = self.gsdbs.credentials["signalserver"]
@@ -68,11 +68,17 @@ def channel_send(logger, channel, message):
 
 
 def syncify_async_function(async_func):
-    loop = asyncio.get_event_loop()
-    if loop is None:
+    try:
+        loop = asyncio.get_event_loop()
+    except:
+        loop = asyncio.new_event_loop()
+        asyncio.set_event_loop(loop)
+
+    if loop is None or not loop.is_running():
         print("loop is none")
         loop = asyncio.new_event_loop()
         asyncio.set_event_loop(loop)
+
     def sync_func(*args, **kwargs):
         if not loop.is_running():
             loop.run_until_complete(asyncio.sleep(0))
@@ -243,7 +249,6 @@ class GSPeerConnectionBroadcasterPiSocketv2:
 
                     syncify_async_function(setremotedescription)
 
-
         @self.sio.event
         def disconnectBroadcaster(id, desc):
             if id in self.peerConnections:
